@@ -5,11 +5,11 @@ use cc::Build;
 fn select_impl() -> &'static str {
     // Select the unix shim
     #[cfg(target_family = "unix")]
-    return "src/select_impl/select_unix.c";
+    return "src/select/select_unix.c";
 
     // Select the windows shim
     #[cfg(target_family = "windows")]
-    return "src/select_impl/select_win.c";
+    return "src/select/select_win.c";
 
     // Panic if we run on a different platform
     #[allow(unreachable_code)]
@@ -22,6 +22,7 @@ fn select_impl() -> &'static str {
 fn main() {
     Build::new()
         .file(select_impl())
+        .extra_warnings(true)
         .warnings_into_errors(true)
         .compile("select");
 }
